# Digital Signature Tool

This tool generates and verifies digital signatures for files using SHA-256 hashing and a secret key.

Version : 0.0.1



## Installation

You can install the package using pip:

pip install digitalsigtool

After Installing you will need to execute in command prompt or terminal directly using digitalsigtool

